# text

## Objects

 * <span class="badge object-type-enum"></span> [CodeLanguage](./object-CodeLanguage.md)
 * <span class="badge object-type-class"></span> [CodeOptions](./object-CodeOptions.md)
 * <span class="badge object-type-class"></span> [Options](./object-Options.md)
 * <span class="badge object-type-enum"></span> [TextMode](./object-TextMode.md)
## Builders

 * <span class="badge builder"></span> [CodeOptions](./builder-CodeOptions.md)
 * <span class="badge builder"></span> [Panel](./builder-Panel.md)
